summaryrefslogtreecommitdiffstats
path: root/commands/commands_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'commands/commands_test.go')
-rw-r--r--commands/commands_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/commands/commands_test.go b/commands/commands_test.go
index 3bf2b2e96..9e623e9a2 100644
--- a/commands/commands_test.go
+++ b/commands/commands_test.go
@@ -190,7 +190,7 @@ func TestFlags(t *testing.T) {
"--navigateToChanged",
"--disableLiveReload",
"--noHTTPCache",
- "--i18n-warnings",
+ "--printI18nWarnings",
"--destination=/tmp/mydestination",
"-b=https://example.com/b/",
"--port=1366",
@@ -223,7 +223,7 @@ func TestFlags(t *testing.T) {
// The flag is named printPathWarnings
c.Assert(cfg.GetBool("logPathWarnings"), qt.Equals, true)
// The flag is named i18n-warnings
c.Assert(cfg.GetBool("logI18nWarnings"), qt.Equals, true)
},
},
@@ -223,7 +223,7 @@ func TestFlags(t *testing.T) {
// The flag is named printPathWarnings
c.Assert(cfg.GetBool("logPathWarnings"), qt.Equals, true)
- // The flag is named i18n-warnings
+ // The flag is named printI18nWarnings
c.Assert(cfg.GetBool("logI18nWarnings"), qt.Equals, true)
},